package mimemagic

const globMaxLen = 18

var globs = []glob{
	textPattern{pattern{[]matcher{byteRange{'0', '9'}, byteRange{'0', '9'}, byteRange{'0', '9'}, value(".vdr")}, 7}, false, 961, 50},
	suffixPattern{pattern{[]matcher{value(".anim"), any{byteRange{'1', '9'}, list("j")}}, 6}, false, 969, 50},
}

var suffixes = map[string][]simpleGlob{
	"%":                  {{50, 470}},
	",v":                 {{50, 827}},
	".123":               {{50, 97}},
	".32x":               {{50, 281}},
	".3ds":               {{50, 630}},
	".3g2":               {{50, 953}},
	".3ga":               {{50, 952}},
	".3gp":               {{50, 952}},
	".3gp2":              {{50, 953}},
	".3gpp":              {{50, 952}},
	".3gpp2":             {{50, 953}},
	".602":               {{50, 459}},
	".669":               {{50, 567}},
	".7z":                {{50, 191}},
	".a":                 {{50, 204}},
	".a26":               {{50, 207}},
	".a78":               {{50, 208}},
	".aa":                {{50, 573}},
	".aac":               {{50, 537}},
	".aax":               {{50, 573}},
	".abc":               {{50, 837}},
	".abw":               {{50, 192}},
	".abw.crashed":       {{50, 192}},
	".abw.gz":            {{50, 192}},
	".ac3":               {{50, 538}},
	".ace":               {{50, 193}},
	".adb":               {{50, 846}},
	".adf":               {{50, 195}},
	".ads":               {{50, 846}},
	".adts":              {{50, 537}},
	".afm":               {{50, 259}},
	".ag":                {{50, 632}},
	".agb":               {{50, 278}},
	".ai":                {{50, 15}},
	".aif":               {{50, 555}},
	".aifc":              {{50, 554}},
	".aiff":              {{50, 555}},
	".aiffc":             {{50, 554}},
	".al":                {{50, 409}},
	".alz":               {{50, 194}},
	".amr":               {{50, 535}},
	".amz":               {{50, 556}},
	".ani":               {{50, 389}},
	".anki":              {{50, 197}},
	".anx":               {{50, 3}},
	".ape":               {{50, 557}},
	".apk":               {{50, 69}},
	".apkg":              {{50, 198}},
	".appimage":          {{50, 70}, {50, 305}},
	".ar":                {{50, 204}},
	".arj":               {{50, 205}},
	".arw":               {{50, 681}},
	".as":                {{50, 201}},
	".asc":               {{50, 827}, {10, 36}, {10, 37}, {10, 38}},
	".ascii85":           {{50, 847}},
	".asf":               {{50, 101}},
	".asp":               {{50, 206}},
	".ass":               {{50, 927}, {10, 537}},
	".asx":               {{50, 569}},
	".atom":              {{50, 4}},
	".au":                {{50, 540}},
	".aup":               {{50, 210}},
	".automount":         {{50, 931}},
	".avf":               {{50, 979}},
	".avi":               {{50, 979}},
	".aw":                {{50, 202}},
	".awb":               {{50, 536}},
	".awk":               {{50, 211}},
	".axa":               {{50, 539}},
	".axv":               {{50, 954}},
	".b2a":               {{50, 6}},
	".b64":               {{50, 5}},
	".bak":               {{50, 470}},
	".base32":            {{50, 849}},
	".base64":            {{50, 5}},
	".bay":               {{50, 654}},
	".bcpio":             {{50, 212}},
	".bdf":               {{50, 260}},
	".bdm":               {{50, 959}},
	".bdmv":              {{50, 959}},
	".bib":               {{50, 850}},
	".bin":               {{50, 432}, {50, 434}},
	".blend":             {{50, 214}},
	".blender":           {{50, 214}},
	".bmp":               {{50, 597}},
	".bmq":               {{50, 654}},
	".bsdiff":            {{50, 215}},
	".btoa":              {{50, 6}},
	".bz":                {{50, 217}},
	".bz2":               {{50, 217}},
	".c++":               {{50, 852}},
	".cab":               {{50, 102}},
	".cap":               {{50, 182}},
	".cb7":               {{50, 222}},
	".cbl":               {{50, 856}},
	".cbr":               {{50, 75}},
	".cbt":               {{50, 223}},
	".cbz":               {{50, 74}},
	".cc":                {{50, 852}},
	".ccf":               {{50, 224}},
	".ccmx":              {{50, 225}},
	".cda":               {{50, 227}},
	".cdf":               {{50, 184}, {50, 393}},
	".cdr":               {{50, 76}},
	".cer":               {{75, 49}},
	".cert":              {{55, 49}, {50, 514}},
	".cgb":               {{50, 274}},
	".cgm":               {{50, 598}},
	".chm":               {{50, 108}},
	".chrt":              {{50, 319}},
	".cl":                {{50, 909}},
	".class":             {{50, 308}},
	".clpi":              {{50, 959}},
	".cls":               {{50, 933}},
	".cmake":             {{50, 855}},
	".cob":               {{50, 856}},
	".coffee":            {{50, 73}},
	".course":            {{50, 340}},
	".cpi":               {{50, 959}},
	".cpio":              {{50, 235}},
	".cpio.gz":           {{50, 236}},
	".cpp":               {{50, 852}},
	".cr2":               {{50, 634}},
	".crdownload":        {{50, 404}},
	".crl":               {{75, 51}},
	".crt":               {{55, 49}, {50, 514}},
	".crw":               {{50, 635}},
	".cs":                {{50, 859}},
	".cs1":               {{50, 654}},
	".cs2":               {{50, 654}},
	".csh":               {{50, 237}},
	".csr":               {{50, 39}},
	".css":               {{50, 820}},
	".csv":               {{50, 821}},
	".csvs":              {{50, 822}},
	".cue":               {{50, 238}},
	".cur":               {{50, 689}},
	".cxx":               {{50, 852}},
	".d":                 {{50, 864}},
	".dar":               {{50, 239}},
	".dbf":               {{50, 240}},
	".dbk":               {{50, 247}},
	".dc":                {{50, 241}},
	".dcl":               {{50, 862}},
	".dcm":               {{50, 7}},
	".dcr":               {{50, 655}},
	".dds":               {{50, 639}},
	".deb":               {{50, 77}},
	".der":               {{50, 514}},
	".desktop":           {{50, 243}},
	".device":            {{50, 931}},
	".di":                {{50, 864}},
	".dia":               {{50, 244}},
	".dib":               {{50, 597}},
	".diff":              {{50, 912}},
	".divx":              {{50, 979}},
	".djv":               {{50, 619}, {50, 620}},
	".djvu":              {{50, 619}, {50, 620}},
	".dlc":               {{50, 246}},
	".dmg":               {{50, 200}},
	".dmp":               {{50, 182}},
	".dng":               {{50, 631}},
	".doc":               {{50, 27}, {50, 827}},
	".docbook":           {{50, 247}},
	".docm":              {{50, 123}},
	".docx":              {{50, 156}},
	".dot":               {{50, 28}, {50, 838}},
	".dotm":              {{50, 124}},
	".dotx":              {{50, 157}},
	".dsl":               {{50, 863}},
	".dtd":               {{50, 528}},
	".dts":               {{50, 549}},
	".dtshd":             {{50, 550}},
	".dtx":               {{50, 933}},
	".dv":                {{50, 955}},
	".dvi":               {{50, 250}},
	".dvi.bz2":           {{50, 216}},
	".dvi.gz":            {{50, 293}},
	".dwg":               {{50, 621}},
	".dxf":               {{50, 622}},
	".e":                 {{50, 865}},
	".egon":              {{50, 252}},
	".eif":               {{50, 865}},
	".el":                {{50, 866}},
	".emf":               {{50, 600}},
	".eml":               {{50, 804}},
	".emp":               {{50, 78}},
	".enc":               {{50, 942}},
	".ent":               {{50, 529}},
	".eps":               {{50, 641}},
	".eps.bz2":           {{50, 633}},
	".eps.gz":            {{50, 648}},
	".epsf":              {{50, 641}},
	".epsf.bz2":          {{50, 633}},
	".epsf.gz":           {{50, 648}},
	".epsi":              {{50, 641}},
	".epsi.bz2":          {{50, 633}},
	".epsi.gz":           {{50, 648}},
	".epub":              {{50, 9}},
	".erf":               {{50, 654}},
	".erl":               {{50, 867}},
	".es":                {{50, 8}},
	".etheme":            {{50, 251}},
	".etx":               {{50, 925}},
	".exe":               {{50, 380}},
	".exr":               {{50, 642}},
	".ez":                {{50, 2}},
	".f":                 {{50, 868}},
	".f4a":               {{50, 544}},
	".f4b":               {{50, 562}},
	".f4v":               {{50, 960}},
	".f90":               {{50, 868}},
	".f95":               {{50, 868}},
	".fb2":               {{50, 257}},
	".fb2.zip":           {{50, 523}},
	".fd":                {{50, 426}},
	".fds":               {{50, 256}},
	".feature":           {{50, 872}},
	".fff":               {{50, 654}},
	".fgeo":              {{50, 249}},
	".fig":               {{50, 221}, {50, 693}},
	".fits":              {{50, 602}},
	".fkt":               {{50, 334}},
	".fl":                {{50, 258}},
	".flac":              {{50, 541}},
	".flatpak":           {{50, 79}},
	".flatpakref":        {{50, 80}},
	".flatpakrepo":       {{50, 81}},
	".flc":               {{50, 970}},
	".fli":               {{50, 970}},
	".flv":               {{50, 971}},
	".flw":               {{50, 333}},
	".fm":                {{50, 83}},
	".fo":                {{50, 948}},
	".fodg":              {{50, 134}},
	".fodp":              {{50, 138}},
	".fods":              {{50, 141}},
	".fodt":              {{50, 144}},
	".fonts.zip":         {{50, 90}},
	".for":               {{50, 868}},
	".fxm":               {{50, 972}},
	".g3":                {{50, 601}},
	".gb":                {{50, 275}},
	".gba":               {{50, 278}},
	".gbc":               {{50, 274}},
	".gbr":               {{50, 645}},
	".gcode":             {{50, 950}},
	".gcrd":              {{50, 836}},
	".ged":               {{50, 280}},
	".gedcom":            {{50, 280}},
	".gem":               {{50, 460}},
	".gen":               {{50, 282}},
	".geo.json":          {{50, 10}},
	".geojson":           {{50, 10}},
	".gf":                {{50, 462}},
	".gg":                {{50, 277}},
	".gif":               {{50, 604}},
	".gih":               {{50, 646}},
	".glade":             {{50, 284}},
	".gml":               {{50, 11}},
	".gmo":               {{50, 283}},
	".gnc":               {{50, 285}},
	".gnd":               {{50, 12}},
	".gnucash":           {{50, 285}},
	".gnumeric":          {{50, 286}},
	".gnuplot":           {{50, 287}},
	".go":                {{50, 873}},
	".gp":                {{50, 287}},
	".gpg":               {{50, 36}, {50, 37}, {50, 38}},
	".gplt":              {{50, 287}},
	".gpx":               {{50, 13}},
	".gra":               {{50, 289}},
	".gradle":            {{50, 875}},
	".groovy":            {{50, 876}},
	".gsf":               {{50, 272}},
	".gsm":               {{50, 559}},
	".gtar":              {{50, 460}},
	".gv":                {{50, 838}},
	".gvp":               {{50, 874}},
	".gz":                {{50, 14}},
	".h":                 {{50, 854}},
	".h++":               {{50, 851}},
	".h4":                {{50, 296}},
	".h5":                {{50, 296}},
	".hdd":               {{50, 480}},
	".hdf":               {{50, 296}},
	".hdf4":              {{50, 296}},
	".hdf5":              {{50, 296}},
	".hdr":               {{50, 649}},
	".heic":              {{50, 605}},
	".heif":              {{50, 605}},
	".hex":               {{50, 878}, {50, 881}},
	".hfe":               {{50, 297}},
	".hh":                {{50, 851}},
	".hlp":               {{50, 190}},
	".hp":                {{50, 851}},
	".hpgl":              {{50, 86}},
	".hpp":               {{50, 851}},
	".hrd":               {{50, 654}},
	".hs":                {{50, 877}},
	".htm":               {{50, 525}, {50, 824}},
	".html":              {{50, 525}, {50, 824}},
	".hwp":               {{50, 298}},
	".hwt":               {{50, 299}},
	".hxx":               {{50, 851}},
	".ica":               {{50, 300}},
	".icb":               {{50, 686}},
	".icc":               {{50, 88}},
	".icm":               {{50, 88}},
	".icns":              {{50, 650}},
	".ico":               {{50, 623}},
	".icq":               {{50, 301}},
	".ics":               {{50, 819}},
	".idl":               {{50, 880}},
	".ief":               {{50, 606}},
	".iff":               {{50, 651}},
	".iges":              {{50, 806}},
	".igs":               {{50, 806}},
	".ihex":              {{50, 881}},
	".ilbm":              {{50, 651}},
	".ime":               {{50, 879}},
	".img":               {{50, 424}},
	".img.xz":            {{50, 425}},
	".imy":               {{50, 879}},
	".ins":               {{50, 933}},
	".iptables":          {{50, 883}},
	".ipynb":             {{50, 304}},
	".iso":               {{80, 226}, {50, 276}, {50, 432}, {50, 434}, {50, 507}},
	".iso9660":           {{60, 226}},
	".it":                {{50, 561}},
	".it87":              {{50, 306}},
	".j2c":               {{50, 653}},
	".j2k":               {{50, 653}},
	".jad":               {{50, 841}},
	".jar":               {{50, 310}},
	".java":              {{50, 884}},
	".jceks":             {{50, 311}},
	".jks":               {{50, 313}},
	".jng":               {{50, 652}},
	".jnlp":              {{50, 312}},
	".jp2":               {{50, 607}},
	".jpc":               {{50, 653}},
	".jpe":               {{50, 608}},
	".jpeg":              {{50, 608}},
	".jpf":               {{50, 610}},
	".jpg":               {{50, 608}},
	".jpg2":              {{50, 607}},
	".jpgm":              {{50, 609}},
	".jpm":               {{50, 609}},
	".jpr":               {{50, 315}},
	".jpx":               {{50, 315}, {50, 610}},
	".jrd":               {{50, 17}},
	".js":                {{50, 16}},
	".jsm":               {{50, 16}},
	".json":              {{50, 18}},
	".json-patch":        {{50, 19}},
	".jsonld":            {{50, 20}},
	".k25":               {{50, 656}},
	".k3b":               {{50, 316}},
	".k7":                {{50, 467}},
	".kar":               {{50, 542}},
	".karbon":            {{50, 317}},
	".katefl":            {{50, 885}},
	".kcfg":              {{50, 91}},
	".kcfgc":             {{50, 92}},
	".kcsrc":             {{50, 320}},
	".kdc":               {{50, 657}},
	".kdelnk":            {{50, 243}},
	".kdenlive":          {{50, 321}},
	".kdenlivetitle":     {{50, 322}},
	".kexi":              {{50, 325}, {50, 326}},
	".kexic":             {{50, 323}},
	".kexis":             {{50, 324}},
	".key":               {{50, 307}},
	".kfo":               {{50, 327}},
	".kgeo":              {{50, 328}},
	".kgt":               {{50, 329}},
	".kig":               {{50, 331}},
	".kigz":              {{50, 331}},
	".kil":               {{50, 332}},
	".kim":               {{50, 94}},
	".kino":              {{50, 65}},
	".kmdr":              {{50, 337}},
	".kml":               {{50, 84}},
	".kmz":               {{50, 85}},
	".kns":               {{50, 335}},
	".kolf":              {{50, 340}},
	".kolfgame":          {{50, 336}},
	".kon":               {{50, 338}},
	".kopete-emoticons":  {{50, 339}},
	".kourse":            {{50, 340}},
	".kplato":            {{50, 499}},
	".kplatowork":        {{50, 500}},
	".kpm":               {{50, 341}},
	".kpr":               {{50, 342}},
	".kpt":               {{50, 342}},
	".kra":               {{50, 343}},
	".ks":                {{50, 313}},
	".ksp":               {{50, 345}},
	".kth":               {{50, 349}},
	".ktx":               {{50, 611}},
	".kud":               {{50, 351}},
	".kug":               {{50, 501}},
	".kut":               {{50, 350}},
	".kvtml":             {{50, 352}},
	".kwd":               {{50, 354}},
	".kwl":               {{50, 353}},
	".kwt":               {{50, 354}},
	".la":                {{50, 438}},
	".latex":             {{50, 933}},
	".lbm":               {{50, 651}},
	".ldif":              {{50, 886}},
	".lha":               {{50, 357}},
	".lhs":               {{50, 888}},
	".lhz":               {{50, 358}},
	".lnk":               {{50, 381}},
	".lnx":               {{50, 209}},
	".loas":              {{50, 548}},
	".log":               {{50, 889}},
	".lrv":               {{50, 960}},
	".lrz":               {{50, 359}},
	".ltx":               {{50, 933}},
	".lua":               {{50, 890}},
	".lwo":               {{50, 658}},
	".lwob":              {{50, 658}},
	".lwp":               {{50, 98}},
	".lws":               {{50, 659}},
	".ly":                {{50, 887}},
	".lyx":               {{50, 361}},
	".lz":                {{50, 364}},
	".lz4":               {{50, 362}},
	".lzh":               {{50, 357}},
	".lzma":              {{50, 366}},
	".lzo":               {{50, 368}},
	".m":                 {{50, 185}, {50, 892}, {50, 905}},
	".m15":               {{50, 567}},
	".m1u":               {{50, 964}},
	".m2t":               {{50, 959}},
	".m2ts":              {{50, 959}},
	".m3u":               {{50, 71}, {50, 568}},
	".m3u8":              {{50, 71}, {50, 568}},
	".m4":                {{50, 370}},
	".m4a":               {{50, 544}},
	".m4b":               {{50, 562}},
	".m4r":               {{50, 563}},
	".m4u":               {{50, 964}},
	".m4v":               {{50, 960}},
	".m7":                {{50, 466}},
	".mab":               {{50, 373}},
	".mak":               {{50, 891}},
	".man":               {{50, 471}},
	".manifest":          {{50, 818}},
	".markdown":          {{50, 826}},
	".mbox":              {{50, 24}},
	".md":                {{50, 826}},
	".mdb":               {{50, 100}},
	".mdc":               {{50, 654}},
	".mdi":               {{50, 624}},
	".mdx":               {{50, 281}},
	".me":                {{50, 935}},
	".med":               {{50, 567}},
	".meta4":             {{50, 26}},
	".metalink":          {{50, 25}},
	".mgp":               {{50, 372}},
	".mht":               {{50, 376}},
	".mhtml":             {{50, 376}},
	".mid":               {{50, 542}},
	".midi":              {{50, 542}},
	".mif":               {{50, 375}},
	".minipsf":           {{50, 565}},
	".mj2":               {{50, 957}},
	".mjp2":              {{50, 957}},
	".mjpeg":             {{50, 975}},
	".mjpg":              {{50, 975}},
	".mjs":               {{50, 16}},
	".mk":                {{50, 891}},
	".mk3d":              {{50, 974}},
	".mka":               {{50, 564}},
	".mkd":               {{50, 826}},
	".mkv":               {{50, 973}},
	".ml":                {{50, 906}},
	".mli":               {{50, 906}},
	".mlt":               {{50, 958}},
	".mm":                {{50, 936}},
	".mmf":               {{50, 444}},
	".mml":               {{50, 23}},
	".mng":               {{50, 976}},
	".mo":                {{50, 283}, {50, 897}},
	".mo3":               {{50, 566}},
	".mobi":              {{50, 378}},
	".moc":               {{50, 896}},
	".mod":               {{50, 567}},
	".mof":               {{50, 898}},
	".moov":              {{50, 963}},
	".mos":               {{50, 654}},
	".mount":             {{50, 931}},
	".mov":               {{50, 963}},
	".movie":             {{50, 982}},
	".mp+":               {{50, 571}},
	".mp2":               {{50, 543}, {50, 961}},
	".mp3":               {{50, 545}},
	".mp4":               {{50, 960}},
	".mpc":               {{50, 571}},
	".mpe":               {{50, 961}},
	".mpeg":              {{50, 961}},
	".mpg":               {{50, 961}},
	".mpga":              {{50, 545}},
	".mpl":               {{50, 959}},
	".mpls":              {{50, 959}},
	".mpp":               {{50, 571}},
	".mrl":               {{50, 900}},
	".mrml":              {{50, 900}},
	".mrw":               {{50, 661}},
	".ms":                {{50, 937}},
	".msi":               {{50, 383}},
	".msod":              {{50, 662}},
	".msx":               {{50, 386}},
	".mtm":               {{50, 567}},
	".mts":               {{50, 959}},
	".mtxcfg":            {{50, 377}},
	".mup":               {{50, 902}},
	".mxf":               {{50, 29}},
	".mxu":               {{50, 964}},
	".n64":               {{50, 387}},
	".nb":                {{80, 186}, {50, 22}},
	".nc":                {{50, 393}},
	".nds":               {{50, 395}},
	".nef":               {{50, 664}},
	".nes":               {{50, 392}},
	".nez":               {{50, 392}},
	".nfo":               {{50, 903}},
	".ngc":               {{50, 390}},
	".ngp":               {{50, 391}},
	".not":               {{50, 902}},
	".notifyrc":          {{50, 93}},
	".nsc":               {{50, 394}},
	".nsv":               {{50, 980}},
	".nzb":               {{50, 396}},
	".o":                 {{50, 397}},
	".obj":               {{50, 464}},
	".ocl":               {{50, 907}},
	".oda":               {{50, 31}},
	".odb":               {{50, 130}},
	".odc":               {{50, 128}},
	".odf":               {{50, 131}},
	".odg":               {{50, 133}},
	".odi":               {{50, 136}},
	".odm":               {{50, 145}},
	".odp":               {{50, 137}},
	".ods":               {{50, 140}},
	".odt":               {{50, 143}},
	".oga":               {{50, 546}, {50, 558}, {50, 581}, {50, 585}},
	".ogg":               {{50, 546}, {50, 558}, {50, 581}, {50, 585}, {50, 962}, {50, 983}},
	".ogm":               {{50, 981}},
	".ogv":               {{50, 962}},
	".ogx":               {{50, 32}},
	".okular":            {{50, 96}},
	".old":               {{50, 470}},
	".oleo":              {{50, 399}},
	".ooc":               {{50, 908}},
	".opml":              {{50, 910}},
	".oprc":              {{50, 158}},
	".opus":              {{50, 546}, {50, 572}},
	".ora":               {{50, 612}},
	".orf":               {{50, 665}},
	".osc":               {{50, 400}},
	".osd":               {{50, 502}},
	".osm":               {{50, 400}},
	".otc":               {{50, 129}},
	".otf":               {{50, 132}, {50, 593}},
	".otg":               {{50, 135}},
	".oth":               {{50, 148}},
	".otm":               {{50, 146}},
	".otp":               {{50, 139}},
	".ots":               {{50, 142}},
	".ott":               {{50, 147}},
	".ova":               {{50, 481}},
	".ovf":               {{50, 482}},
	".owl":               {{50, 58}},
	".owx":               {{50, 33}},
	".oxps":              {{50, 34}},
	".oxt":               {{50, 149}},
	".p":                 {{50, 911}},
	".p10":               {{50, 39}},
	".p12":               {{75, 41}},
	".p65":               {{50, 401}},
	".p7b":               {{50, 43}, {50, 411}},
	".p7c":               {{50, 43}},
	".p7m":               {{50, 43}},
	".p7s":               {{50, 45}},
	".p8":                {{75, 46}},
	".p8e":               {{50, 48}},
	".pack":              {{50, 314}},
	".pak":               {{50, 402}},
	".par2":              {{50, 403}},
	".part":              {{50, 404}},
	".pas":               {{50, 911}},
	".pat":               {{50, 647}},
	".patch":             {{50, 912}},
	".path":              {{50, 931}},
	".pbm":               {{50, 673}},
	".pcap":              {{50, 182}},
	".pcd":               {{50, 669}},
	".pce":               {{50, 405}},
	".pcf":               {{50, 229}, {50, 265}},
	".pcf.gz":            {{50, 265}},
	".pcf.z":             {{50, 265}},
	".pcl":               {{50, 87}},
	".pct":               {{50, 671}},
	".pcx":               {{50, 627}},
	".pdb":               {{50, 158}, {50, 199}},
	".pdc":               {{50, 199}},
	".pdf":               {{50, 35}},
	".pdf.bz2":           {{50, 219}},
	".pdf.gz":            {{50, 294}},
	".pdf.lz":            {{50, 369}},
	".pdf.xz":            {{50, 520}},
	".pef":               {{50, 668}},
	".pem":               {{50, 407}, {50, 514}},
	".perl":              {{50, 409}},
	".pfa":               {{50, 272}},
	".pfb":               {{50, 272}},
	".pfx":               {{55, 41}},
	".pgm":               {{50, 674}},
	".pgn":               {{50, 72}},
	".pgp":               {{50, 36}, {50, 37}, {50, 38}},
	".php":               {{50, 410}},
	".php3":              {{50, 410}},
	".php4":              {{50, 410}},
	".php5":              {{50, 410}},
	".phps":              {{50, 410}},
	".pic":               {{50, 649}, {50, 670}},
	".pict":              {{50, 671}},
	".pict1":             {{50, 671}},
	".pict2":             {{50, 671}},
	".pk":                {{50, 463}},
	".pkcs8":             {{55, 46}},
	".pkg":               {{50, 515}},
	".pkipath":           {{50, 53}},
	".pkr":               {{50, 37}},
	".pl":                {{50, 409}},
	".pla":               {{50, 560}},
	".plan":              {{50, 503}},
	".planwork":          {{50, 504}},
	".plasmoid":          {{50, 413}},
	".pln":               {{50, 412}},
	".pls":               {{50, 579}},
	".pm":                {{50, 401}, {50, 409}},
	".pm6":               {{50, 401}},
	".pmd":               {{50, 401}},
	".png":               {{50, 613}},
	".pnm":               {{50, 672}},
	".pntg":              {{50, 660}},
	".pnx":               {{50, 654}},
	".po":                {{50, 870}},
	".pod":               {{50, 409}},
	".por":               {{50, 451}},
	".pot":               {{50, 109}, {50, 871}},
	".potm":              {{50, 114}},
	".potx":              {{50, 153}},
	".ppam":              {{50, 110}},
	".ppm":               {{50, 675}},
	".pps":               {{50, 109}},
	".ppsm":              {{50, 113}},
	".ppsx":              {{50, 152}},
	".ppt":               {{50, 109}},
	".pptm":              {{50, 111}},
	".pptx":              {{50, 150}},
	".ppz":               {{50, 109}},
	".pqa":               {{50, 158}},
	".prc":               {{50, 158}, {50, 378}},
	".ps":                {{50, 54}},
	".ps.bz2":            {{50, 220}},
	".ps.gz":             {{50, 295}},
	".psd":               {{50, 618}},
	".psf":               {{50, 264}, {50, 575}},
	".psf.gz":            {{50, 292}},
	".psflib":            {{50, 576}},
	".psid":              {{50, 547}},
	".psw":               {{50, 414}},
	".pub":               {{50, 115}},
	".pw":                {{50, 416}},
	".py":                {{60, 913}, {50, 914}},
	".py3":               {{60, 914}},
	".py3x":              {{60, 914}},
	".pyc":               {{50, 417}},
	".pyo":               {{50, 417}},
	".pyx":               {{60, 913}},
	".qd":                {{50, 426}},
	".qif":               {{50, 423}, {50, 676}},
	".qml":               {{50, 915}},
	".qmlproject":        {{50, 915}},
	".qmltypes":          {{50, 915}},
	".qp":                {{50, 418}},
	".qt":                {{50, 963}},
	".qti":               {{50, 419}},
	".qti.gz":            {{50, 419}},
	".qtif":              {{50, 676}},
	".qtl":               {{50, 422}},
	".qtvr":              {{50, 963}},
	".quanta":            {{50, 420}},
	".ra":                {{50, 551}},
	".raf":               {{50, 644}},
	".ram":               {{50, 56}},
	".raml":              {{50, 57}},
	".rar":               {{50, 159}},
	".ras":               {{50, 636}},
	".raw":               {{50, 666}},
	".raw-disk-image":    {{50, 424}},
	".raw-disk-image.xz": {{50, 425}},
	".rax":               {{50, 551}},
	".rb":                {{50, 430}},
	".rc":                {{50, 95}},
	".rdc":               {{50, 654}},
	".rdf":               {{50, 58}},
	".rdfs":              {{50, 58}},
	".reg":               {{50, 901}},
	".rej":               {{50, 917}},
	".rgb":               {{50, 677}},
	".rle":               {{50, 614}},
	".rm":                {{50, 160}},
	".rmj":               {{50, 160}},
	".rmm":               {{50, 160}},
	".rms":               {{50, 160}},
	".rmvb":              {{50, 160}},
	".rmx":               {{50, 160}},
	".rnc":               {{50, 59}},
	".rng":               {{50, 60}, {50, 527}},
	".roff":              {{50, 834}},
	".rp":                {{50, 625}},
	".rpm":               {{50, 428}},
	".rs":                {{50, 830}},
	".rsdf":              {{50, 429}},
	".rss":               {{50, 61}},
	".rst":               {{50, 919}},
	".rt":                {{50, 840}},
	".rtf":               {{50, 62}},
	".rtx":               {{50, 829}},
	".rv":                {{50, 965}},
	".rvx":               {{50, 965}},
	".rw2":               {{50, 667}},
	".s19":               {{50, 926}},
	".s28":               {{50, 926}},
	".s37":               {{50, 926}},
	".s3m":               {{50, 578}},
	".sam":               {{50, 196}},
	".sami":              {{50, 431}},
	".sap":               {{50, 468}},
	".sass":              {{50, 920}},
	".sav":               {{50, 452}},
	".scala":             {{50, 921}},
	".scm":               {{50, 922}},
	".scope":             {{50, 931}},
	".scss":              {{50, 924}},
	".sda":               {{50, 166}},
	".sdc":               {{50, 164}},
	".sdd":               {{50, 167}},
	".sdp":               {{50, 63}, {50, 167}},
	".sds":               {{50, 165}},
	".sdw":               {{50, 170}},
	".seg":               {{50, 344}},
	".service":           {{50, 861}, {50, 931}},
	".sfc":               {{50, 127}},
	".sfd":               {{50, 82}},
	".sg":                {{50, 436}},
	".sgb":               {{50, 275}},
	".sgf":               {{50, 288}},
	".sgi":               {{50, 678}},
	".sgl":               {{50, 170}},
	".sgm":               {{50, 831}},
	".sgml":              {{50, 831}},
	".sgrd":              {{50, 347}},
	".sh":                {{50, 440}},
	".shape":             {{50, 245}},
	".shar":              {{50, 437}},
	".shn":               {{50, 441}},
	".shp":               {{50, 253}},
	".shx":               {{50, 254}},
	".siag":              {{50, 442}},
	".sid":               {{50, 547}},
	".sig":               {{50, 38}},
	".sik":               {{50, 470}},
	".sis":               {{50, 181}},
	".sisx":              {{50, 1002}},
	".sit":               {{50, 454}},
	".siv":               {{50, 64}},
	".sk":                {{50, 680}},
	".sk1":               {{50, 680}},
	".skr":               {{50, 37}},
	".skz":               {{50, 456}},
	".sldm":              {{50, 112}},
	".sldx":              {{50, 151}},
	".slice":             {{50, 931}},
	".slk":               {{50, 832}},
	".smaf":              {{50, 444}},
	".smc":               {{50, 127}},
	".smd":               {{50, 168}, {50, 282}},
	".smf":               {{50, 169}},
	".smi":               {{50, 65}, {50, 431}},
	".smil":              {{50, 65}},
	".sml":               {{50, 65}},
	".sms":               {{50, 447}},
	".snap":              {{50, 161}},
	".snd":               {{50, 540}},
	".snf":               {{50, 266}},
	".snf.gz":            {{50, 266}},
	".snf.z":             {{50, 266}},
	".so":                {{50, 439}},
	".socket":            {{50, 931}},
	".spc":               {{50, 43}, {50, 411}},
	".spd":               {{50, 267}},
	".spec":              {{50, 918}},
	".spkac":             {{50, 449}},
	".spl":               {{50, 68}},
	".spm":               {{50, 448}},
	".spx":               {{50, 580}},
	".sql":               {{50, 66}},
	".sqlite2":           {{50, 453}},
	".sqlite3":           {{50, 162}},
	".sqsh":              {{50, 163}},
	".sr2":               {{50, 682}},
	".src":               {{50, 505}},
	".src.rpm":           {{50, 448}},
	".srec":              {{50, 926}},
	".srf":               {{50, 683}},
	".srt":               {{50, 455}},
	".ss":                {{50, 922}},
	".ssa":               {{50, 927}},
	".stc":               {{50, 172}},
	".std":               {{50, 174}},
	".sti":               {{50, 176}},
	".stl":               {{50, 807}},
	".stm":               {{50, 582}},
	".stw":               {{50, 180}},
	".sty":               {{50, 933}},
	".sub":               {{50, 895}, {50, 899}, {50, 928}},
	".sun":               {{50, 684}},
	".sv":                {{50, 930}},
	".sv4cpio":           {{50, 457}},
	".sv4crc":            {{50, 458}},
	".svg":               {{50, 615}},
	".svgz":              {{50, 616}},
	".svh":               {{50, 929}},
	".svm":               {{50, 685}},
	".swap":              {{50, 931}},
	".swf":               {{50, 68}},
	".swm":               {{50, 382}},
	".sxc":               {{50, 171}},
	".sxd":               {{50, 173}},
	".sxg":               {{50, 179}},
	".sxi":               {{50, 175}},
	".sxm":               {{50, 177}},
	".sxw":               {{50, 178}},
	".sylk":              {{50, 832}},
	".t":                 {{10, 409}, {10, 834}},
	".t2t":               {{50, 939}},
	".tar":               {{50, 460}},
	".tar.bz":            {{50, 218}},
	".tar.bz2":           {{50, 218}},
	".tar.gz":            {{50, 233}},
	".tar.lrz":           {{50, 360}},
	".tar.lz":            {{50, 365}},
	".tar.lz4":           {{50, 363}},
	".tar.lzma":          {{50, 367}},
	".tar.lzo":           {{50, 475}},
	".tar.xz":            {{50, 519}},
	".tar.z":             {{50, 461}},
	".target":            {{50, 931}},
	".taz":               {{50, 461}},
	".tb2":               {{50, 218}},
	".tbz":               {{50, 218}},
	".tbz2":              {{50, 218}},
	".tcl":               {{50, 932}},
	".tex":               {{50, 933}},
	".texi":              {{50, 934}},
	".texinfo":           {{50, 934}},
	".tga":               {{50, 686}},
	".tgz":               {{50, 233}},
	".theme":             {{50, 465}},
	".themepack":         {{50, 509}},
	".tif":               {{50, 617}},
	".tiff":              {{50, 617}},
	".timer":             {{50, 931}},
	".tk":                {{50, 932}},
	".tlrz":              {{50, 360}},
	".tlz":               {{50, 367}},
	".tnef":              {{50, 116}},
	".tnf":               {{50, 116}},
	".toc":               {{50, 228}},
	".torrent":           {{50, 213}},
	".tox":               {{50, 946}},
	".tpic":              {{50, 686}},
	".tr":                {{50, 834}},
	".trig":              {{50, 67}},
	".ts":                {{50, 839}, {50, 959}},
	".tsv":               {{50, 833}},
	".tta":               {{50, 583}},
	".ttc":               {{50, 592}},
	".ttf":               {{50, 594}},
	".ttl":               {{50, 835}},
	".ttx":               {{50, 271}},
	".tuberling":         {{50, 473}},
	".twig":              {{50, 938}},
	".txt":               {{50, 827}},
	".txz":               {{50, 519}},
	".tzo":               {{50, 475}},
	".udeb":              {{50, 77}},
	".ufraw":             {{50, 476}},
	".ui":                {{50, 242}, {50, 290}},
	".uil":               {{50, 940}},
	".uin":               {{50, 301}},
	".ult":               {{50, 567}},
	".unf":               {{50, 392}},
	".uni":               {{50, 567}},
	".unif":              {{50, 392}},
	".url":               {{50, 384}},
	".ustar":             {{50, 478}},
	".uu":                {{50, 942}},
	".uue":               {{50, 942}},
	".v":                 {{50, 944}},
	".v64":               {{50, 387}},
	".vala":              {{50, 943}},
	".vapi":              {{50, 943}},
	".vb":                {{50, 479}},
	".vbox":              {{50, 483}},
	".vbox-extpack":      {{50, 484}},
	".vcard":             {{50, 836}},
	".vcf":               {{50, 836}},
	".vcs":               {{50, 819}},
	".vct":               {{50, 836}},
	".vda":               {{50, 686}},
	".vdi":               {{50, 485}},
	".vhd":               {{50, 486}, {50, 945}},
	".vhdl":              {{50, 945}},
	".viv":               {{50, 966}},
	".vivo":              {{50, 966}},
	".vlc":               {{50, 568}},
	".vmdk":              {{50, 487}, {50, 492}},
	".vmsn":              {{50, 489}},
	".vmtm":              {{50, 490}},
	".vmx":               {{50, 488}, {50, 491}},
	".vmxf":              {{50, 493}},
	".vob":               {{50, 961}},
	".voc":               {{50, 584}},
	".vor":               {{50, 170}},
	".vrm":               {{50, 808}},
	".vrml":              {{50, 808}},
	".vsd":               {{50, 183}},
	".vsdm":              {{50, 117}},
	".vsdx":              {{50, 118}},
	".vss":               {{50, 183}},
	".vssm":              {{50, 119}},
	".vssx":              {{50, 120}},
	".vst":               {{50, 183}, {50, 686}},
	".vstm":              {{50, 121}},
	".vstx":              {{50, 122}},
	".vsw":               {{50, 183}},
	".vtt":               {{50, 844}},
	".wad":               {{80, 248}, {50, 508}},
	".war":               {{50, 506}},
	".wav":               {{50, 586}},
	".wax":               {{50, 569}},
	".wb1":               {{50, 421}},
	".wb2":               {{50, 421}},
	".wb3":               {{50, 421}},
	".wbmp":              {{50, 626}},
	".wcm":               {{50, 125}},
	".wdb":               {{50, 125}},
	".webm":              {{50, 968}},
	".webp":              {{50, 628}, {50, 688}},
	".westley":           {{50, 958}},
	".wiki":              {{50, 845}},
	".wim":               {{50, 382}},
	".wk1":               {{50, 97}},
	".wk3":               {{50, 97}},
	".wk4":               {{50, 97}},
	".wkdownload":        {{50, 404}},
	".wks":               {{50, 97}, {50, 125}},
	".wl":                {{50, 187}},
	".wma":               {{50, 570}},
	".wmf":               {{50, 629}},
	".wml":               {{50, 842}},
	".wmls":              {{50, 843}},
	".wmp":               {{50, 977}},
	".wmv":               {{50, 978}},
	".wmx":               {{50, 569}},
	".woff":              {{50, 595}},
	".woff2":             {{50, 596}},
	".wp":                {{50, 188}},
	".wp4":               {{50, 188}},
	".wp5":               {{50, 188}},
	".wp6":               {{50, 188}},
	".wpd":               {{50, 188}},
	".wpg":               {{50, 512}},
	".wpl":               {{50, 126}},
	".wpp":               {{50, 188}},
	".wps":               {{50, 125}},
	".wql":               {{50, 356}},
	".wri":               {{50, 385}},
	".wrl":               {{50, 808}},
	".ws":                {{50, 511}},
	".wsc":               {{50, 510}},
	".wsgi":              {{60, 913}},
	".wv":                {{50, 587}},
	".wvc":               {{50, 588}},
	".wvp":               {{50, 587}},
	".wvx":               {{50, 569}},
	".wwf":               {{50, 513}},
	".x3f":               {{50, 679}},
	".xac":               {{50, 285}},
	".xar":               {{50, 515}},
	".xbel":              {{50, 516}},
	".xbl":               {{50, 527}},
	".xbm":               {{50, 690}},
	".xcf":               {{50, 691}},
	".xcf.bz2":           {{50, 637}},
	".xcf.gz":            {{50, 637}},
	".xdgapp":            {{50, 79}},
	".xhe":               {{50, 548}},
	".xht":               {{50, 525}},
	".xhtml":             {{50, 525}},
	".xi":                {{50, 589}},
	".xla":               {{50, 103}},
	".xlam":              {{50, 104}},
	".xlc":               {{50, 103}},
	".xld":               {{50, 103}},
	".xlf":               {{50, 526}},
	".xliff":             {{50, 526}},
	".xll":               {{50, 103}},
	".xlm":               {{50, 103}},
	".xlr":               {{50, 125}},
	".xls":               {{50, 103}},
	".xlsb":              {{50, 105}},
	".xlsm":              {{50, 106}},
	".xlsx":              {{50, 154}},
	".xlt":               {{50, 103}},
	".xltm":              {{50, 107}},
	".xltx":              {{50, 155}},
	".xlw":               {{50, 103}},
	".xm":                {{50, 590}},
	".xmf":               {{50, 591}},
	".xmi":               {{50, 477}, {50, 947}},
	".xmi.tar.bz2":       {{50, 477}},
	".xmi.tgz":           {{50, 477}},
	".xml":               {{50, 527}},
	".xpi":               {{50, 517}},
	".xpm":               {{50, 694}},
	".xps":               {{50, 34}},
	".xsd":               {{50, 527}, {50, 530}},
	".xsl":               {{50, 531}},
	".xslfo":             {{50, 948}},
	".xslt":              {{50, 531}},
	".xspf":              {{50, 532}},
	".xul":               {{50, 99}},
	".xwd":               {{50, 695}},
	".xxe":               {{50, 949}},
	".xz":                {{50, 518}},
	".yaml":              {{50, 521}},
	".yml":               {{50, 521}},
	".yt":                {{50, 189}},
	".z":                 {{50, 232}},
	".z64":               {{50, 387}},
	".zabw":              {{50, 192}},
	".zip":               {{50, 533}},
	".zoo":               {{50, 524}},
	".zsav":              {{50, 452}},
	".zz":                {{50, 534}},
	"~":                  {{50, 470}},
}

var suffixesCS = map[string][]simpleGlob{
	".C":  {{50, 852}},
	".c":  {{50, 860}},
	".gs": {{50, 869}},
}

var prefixes = map[string][]simpleGlob{
	"cachegrind.out": {{50, 318}},
	"callgrind.out":  {{50, 318}},
	"makefile.":      {{10, 891}},
	"readme":         {{10, 916}},
	"sconscript.":    {{50, 923}},
}

var prefixesCS = map[string][]simpleGlob{}

var text = map[string][]simpleGlob{
	"authors":           {{50, 848}},
	"cacerts":           {{50, 313}},
	"changelog":         {{50, 853}},
	"cmakecache.txt":    {{50, 231}},
	"cmakelists.txt":    {{50, 855}},
	"copying":           {{50, 857}},
	"credits":           {{50, 858}},
	"dicomdir":          {{50, 7}},
	"gmon.out":          {{50, 415}},
	"gnumakefile":       {{50, 891}},
	"install":           {{50, 882}},
	"makefile":          {{50, 891}},
	"meson.build":       {{50, 894}},
	"meson_options.txt": {{50, 894}},
	"pom.xml":           {{50, 893}},
	"rmail":             {{50, 805}},
	"sconscript":        {{50, 923}},
	"sconstruct":        {{50, 923}},
	"settings.xml":      {{50, 893}},
	"winmail.dat":       {{50, 116}},
}

var textCS = map[string][]simpleGlob{
	"core": {{50, 234}},
}
